@@ -95,13 +95,14 @@ class Builder:
         pivots = pd.DataFrame(data=pivots, columns=('pivot',))
 
         candles['cluster'] = clustering.labels_
+        candles['pivots'] = pivots
         prices['cluster'] = clustering.labels_
-        pivots['cluster'] = clustering.labels_
+        prices['pivots'] = pivots
+        # pivots['cluster'] = clustering.labels_
 
-        candles = candles.groupby('cluster').apply(np.array)
-        prices = prices.groupby('cluster').agg({'price': 'mean'}).apply(np.array)
-        pivots = pivots.groupby('cluster').agg({'pivot': 'mean'}).apply(np.array)
+        candles = candles.groupby(['cluster', 'pivots']).apply(np.array)
+        prices = prices.groupby(['cluster', 'pivots']).agg({'price': 'mean'}).apply(np.array)
 
-        data = np.column_stack([candles, prices, pivots])
+        data = np.column_stack([candles, prices])
 
         return data
